@@ -52,16 +52,16 @@ callcase callblocks deffiles makefilename extractcase setlaunch exe start
 _clean_ getblocks getblockelts getrootname definerootcases populatewinners 
 getitem getline getlines getcase getstepsvar tell wash flattenbox enrichbox filterbox givesize 
 $configfile $mypath $exeonfiles $generatechance $file $preventsim $fileconfig $outfile $toshell $report 
-$simnetwork @reportloadsdata @themereports @simtitles @reporttitles @simdata @retrievedata 
+$simnetwork @themereports @simtitles @reporttitles @simdata @retrievedata 
 @keepcolumns @weights @weightsaim @varthemes_report @varthemes_variations @varthemes_steps 
 @rankdata @rankcolumn @reporttempsdata @reportcomfortdata @reportradiationenteringdata 
-@reporttempsstats @files_to_filter @filter_reports @base_columns @maketabledata @filter_columns 
+@report_loadsortemps @files_to_filter @filter_reports @base_columns @maketabledata @filter_columns 
 @files_to_filter @filter_reports @base_columns @maketabledata @filter_columns %vals 
 @sweeps @mediumiters @varinumbers @caseseed @chanceseed @chancedata $dimchance $tee @pars_tocheck 
 $target 
 ); # our @EXPORT = qw( );
 
-$VERSION = '0.40.7'; # our $VERSION = '';
+$VERSION = '0.40.9'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT it a tool for detailed metadesign. It manages parametric explorations through the ESP-r building performance simulation platform and performs optimization by block coordinate descent.';
 
 #################################################################################
@@ -829,9 +829,9 @@ sub deffiles # IT DEFINED THE FILES TO BE CALLED.
 	} 
 	#say $tee  "#\@box!: " . dump ( @box );
 	
-	my @flattened = flattenbox(@box);say $tee  "#\@flattened: " . dump(@flattened) . ", " . scalar(@flattened);
-	my @integrated = integratebox(\@flattened, \%mids, $file); say $tee  "#\@integrated " . dump(@integrated) . ", " . scalar(@integrated);
-	my @finalbox = filterbox(@integrated); say $tee  "#\@finalbox " . dump(@finalbox) . ", " . scalar(@finalbox); 
+	my @flattened = flattenbox(@box); #say $tee  "#\@flattened: " . dump(@flattened) . ", " . scalar(@flattened);
+	my @integrated = integratebox(\@flattened, \%mids, $file); #say $tee  "#\@integrated " . dump(@integrated) . ", " . scalar(@integrated);
+	my @finalbox = filterbox(@integrated); #say $tee  "#\@finalbox " . dump(@finalbox) . ", " . scalar(@finalbox); 
 	
 	say $tee "#Calling to instruct the launch of new searches for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 	my $datatowork = 
@@ -840,7 +840,8 @@ sub deffiles # IT DEFINED THE FILES TO BE CALLED.
 		miditers => \@miditers,  winneritems => \@winneritems, 
 		dirfiles => \%dirfiles, uplift => \@uplift, 
 		basket => \@finalbox   
-	} ; say $tee "\ndumper-datatowork: " . dump($datatowork) . "\n\n";
+	} ;
+	# say $tee "\ndumper-datatowork: " . dump($datatowork) . "\n\n";
 	setlaunch( $datatowork );
 }	
 
@@ -1175,7 +1176,7 @@ The "Sim::OPT::Takechance" module produces efficient search structures for block
 
 The "Sim::OPT::Parcoord3d module receiving as input the data for a bi-dimensional parallel coordinate plot in a cvs file produces as output an Autolisp file that can be used from Autocad or an Intellicad-derived 3D CAD program to obtain a 3D parallel coordinate plot (that can subsequently saved in dwg, dxf or other suitable format). A section of the configuration file for "Sim::OPT" is dedicated to the "Sim::OPT::Parcoord3d" module.
 
-OPT is a program I have begun to write as a side project in 2008 with no funding. It is the first real program I attempted to write. From time to time I add some parts to it.
+OPT is still in an alpha stage. I will not add functionalities to it until it is in beta.
 
 Gian Luca Brunetti, Politecnico di Milano
 gianluca.brunetti@polimi.it
