@@ -29,11 +29,6 @@ use Data::Dumper;
 #$Data::Dumper::Terse  = 1;
 use Data::Dump qw(dump);
 use feature 'say';
-#use feature qw(postderef);
-#no warnings qw(experimental::postderef);
-#use Sub::Signatures;
-#no warnings qw(Sub::Signatures); 
-#no strict 'refs';
 no strict; 
 no warnings;
 
@@ -75,7 +70,6 @@ sub report # This function retrieves the results of interest from the text file
 	$toshell = $main::toshell;
 	$report = $main::report;
 	$simnetwork = $main::simnetwork;
-	$reportloadsdata = $main::reportloadsdata;
 	
 	$tee = new IO::Tee(\*STDOUT, ">>$toshell"); # GLOBAL ZZZ
 	
@@ -102,7 +96,7 @@ sub report # This function retrieves the results of interest from the text file
 	@reporttempsdata = @main::reporttempsdata;
 	@reportcomfortdata = @main::reportcomfortdata;
 	@reportradiation = @main::reportradiation;
-	@reporttempsstats = @main::reporttempsstats;
+	@report_loadsortemps = @main::report_loadsortemps;
 	@files_to_filter = @main::files_to_filter;
 	@filter_reports = @main::filter_reports;
 	@base_columns = @main::base_columns;
@@ -195,29 +189,30 @@ sub report # This function retrieves the results of interest from the text file
 			my $simtitle = $simtitles[$counttheme]; say TOSHELL "\$simtitle " . dump($simtitle); ### 
 						
 			my $countreport = 0;
-			my @themes = @$themeref; #say TOSHELL "#THEMES: " . dump(@themes);
-			foreach my $themereport (@themes) ###
+			foreach my $themereport ( @$themeref ) ###
 			{
-				my @themes = @$themeref; #say TOSHELL "#IN: THEMES: " . dump(@themes);
 				$" = " ";
+				my $reporttitle = $reporttitles[$counttheme][$countreport]; say TOSHELL "CALLING-PRE\$reporttitle " . dump($reporttitle);
+				my $simdatum = $reporttitles[$counttheme][0]; say TOSHELL "CALLING-PRE\$simdatum " . dump($simdatum);
+				my @retrievs = @{ $retrievedata[$counttheme][$countreport] }; say TOSHELL "CALLING-PRE\@retrievs " . dump(@retrievs);
+				my $loadsortemps = $report_loadsortemps[$counttheme][$countreport]; say TOSHELL "CALLING-PRE\$loadsortemps " . dump($loadsortemps);
 				
-				my $reporttitle = $reporttitles[$counttheme][$countreport]; #say TOSHELL "CALLING-PRE\$reporttitle " . dump($reporttitle);
-				my $simdatum = $reporttitles[$counttheme][0]; #say TOSHELL "CALLING-PRE\$simdatum " . dump($simdatum);
-				my @retrievs = @{ $retrievedata[$counttheme][$countreport] }; #say TOSHELL "CALLING-PRE\@retrievs " . dump(@retrievs);
+				my $retfile = $retstruct[$countcase][$countblock][$counttheme][$countreport][$countinstance] ; say TOSHELL "#\$retfile " . dump($retfile);
+				say TOSHELL "#CALLING-REPSTRUCT " . dump(@repstruct); # ZZZ
 				
-				my $retfile = $retstruct[$countcase][$countblock][$counttheme][$countreport][$countinstance] ; #say TOSHELL "#\$retfile " . dump($retfile);
-				#say TOSHELL "#CALLING-REPSTRUCT " . dump(@repstruct); # ZZZ
-				
-				#say TOSHELL "CALLING-\$themereport: " . dump($themereport);
-				#say TOSHELL "CALLING-\$countcase: " . dump($countcase);
-				#say TOSHELL "CALLING-\$countblock: " . dump($countblock);
-				#say TOSHELL "CALLING-\$themereport " . dump($themereport);
-				#say TOSHELL "CALLING-\$counttheme " . dump($counttheme);
-				#say TOSHELL "CALLING-\$countreport " . dump($countreport);
-				#say TOSHELL "CALLING-\$retfile: " . dump($retfile);
-				#say TOSHELL "CALLING-\$repfile: " . dump($repfile);
-			
-				@repfilemem = get_files($themereport, $countcase, $countblock, $counttheme, $countreport, $retfile, $repfile, $simtitle, $reporttitle, $simdatum, \@retrievs, $countinstance, \@repfilemem ); 
+				say TOSHELL "CALLING-\$themereport: " . dump($themereport);
+				say TOSHELL "CALLING-\$countcase: " . dump($countcase);
+				say TOSHELL "CALLING-\$countblock: " . dump($countblock);
+				say TOSHELL "CALLING-\$themereport " . dump($themereport);
+				say TOSHELL "CALLING-\$counttheme " . dump($counttheme);
+				say TOSHELL "CALLING-\$countreport " . dump($countreport);
+				say TOSHELL "CALLING-\$retfile: " . dump($retfile);
+				say TOSHELL "CALLING-\$repfile: " . dump($repfile);
+				say TOSHELL "repfilemem BEFORE: " . dump( @repfilemem );
+				@repfilemem = get_files($themereport, $countcase, $countblock, $counttheme, $countreport, $retfile, $repfile, $simtitle,
+					$reporttitle, $simdatum, \@retrievs, $countinstance, \@repfilemem, $loadsortemps ); 
+				say TOSHELL "repfilemem AFTER: " . dump( @repfilemem );
+
 				$countreport++;
 			}
 			$counttheme++;
@@ -225,27 +220,26 @@ sub report # This function retrieves the results of interest from the text file
 		$countinstance++;
 	}
 	
-	push ( @{ $mergestruct[$countcase][$countblock] },  @repfilemem ); say TOSHELL "EXITING dump(\@mergestruct): " . dump(@mergestruct);
-	say TOSHELL "EXITING dump(\@mergestruct): " . dump(@mergestruct);
+	push ( @{ $mergestruct[$countcase][$countblock] }, @repfilemem ); say TOSHELL "\@mergestruct: " . dump(@mergestruct);
 	
-	if ( @repfilemem ~~ @mergecases ) 
-	{ 
-		push ( @mergecases,  @repfilemem );
-	}
-	say TOSHELL "EXITING dump(\@mergecases): " . dump(@mergecases);
+	#if ( @repfilemem ~~ @mergecases ) 
+	#{ 
+	#	push ( @mergecases,  @repfilemem );
+	#}
+	say TOSHELL "\@repfilemem ~~ \@mergecases.";
 		
 	foreach my $instref ( @{ $mergestruct[$countcase][$countblock] } )
 	{
 		my @instance = @{ $instref };
 		foreach (@instance)
 		{
-			print REPFILE "$_"; say TOSHELL " EXITING dump(\$el): " . dump($_);
+			print REPFILE "$_"; say TOSHELL " INSTANCE " . dump($_);
 		}
 		print REPFILE "\n";
 	}
 	close REPFILE;
 		
-	say TOSHELL "EXITING dump(\$repfile): " . dump($repfile);
+	say TOSHELL "\$repfile: " . dump($repfile);
 	close TOSHELL;
 	close OUTFILE;
 	return ( \@repcases, \@repstruct, \@mergestruct, \@mergecases, $repfile ); 
@@ -254,30 +248,33 @@ sub report # This function retrieves the results of interest from the text file
 
 sub get_files
 {
-	say "Extracting temperatures statistics for case " . ($countcase + 1) . ", block " . ($countblock + 1) ;
+	say "Extracting statistics for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", instance: " . ( $countinstance + 1);
 	say TOSHELL "
-	#Extracting temperatures statistics for case " . ($countcase + 1) . ", block " . ($countblock + 1) ;
-	my $themereport = shift; #say TOSHELL "CALLED-\$themereport: " . dump($themereport);
-	my $countcase = shift; #say TOSHELL "CALLED-\$countcase: " . dump($countcase);
-	my $countblock = shift; #say TOSHELL "CALLED-\$countblock: " . dump($countblock);
-	my $counttheme = shift; #say TOSHELL "CALLED-\$counttheme " . dump($counttheme);
-	my $countreport = shift; #say TOSHELL "CALLED-\$countreport " . dump($countreport);
-	my $retfile = shift; #say TOSHELL "CALLED-\$retfile: " . dump($retfile);
-	my $repfile = shift; #say TOSHELL "CALLED-\$repfile: " . dump($repfile);
-	my $simtitle = shift; #say TOSHELL "CALLED-\$simtitle " . dump($simtitle);
-	my $reporttitle = shift; #say TOSHELL "CALLED-\$reporttitle " . dump($reporttitle);
-	my $simdatum = shift; #say TOSHELL "CALLED-\$simdatum " . dump($simdatum);
-	my @retrievs = shift; #say TOSHELL "CALLED-\@retrievs " . dump(@retrievs);
-	my $countinstance = shift; #say TOSHELL "CALLED-\$countinstance " . dump($countinstance);
-	my $swap = shift;
+	#Extracting statistics for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", instance: " . ( $countinstance + 1);
+	my ( $themereport, $countcase, $countblock, $counttheme, $countreport, $retfile, $repfile, 
+		$simtitle, $reporttitle, $simdatum, $retrievsref, $countinstance, $swap, $loadsortemps ) = @_;
+		
+	say TOSHELL "#CALLED-REPSTRUCT " . dump(@repstruct); # ZZZ	
+	say TOSHELL "CALLED-\$themereport: " . dump($themereport);
+	say TOSHELL "CALLED-\$countcase: " . dump($countcase);
+	say TOSHELL "CALLED-\$countblock: " . dump($countblock);
+	say TOSHELL "CALLED-\$themereport " . dump($themereport);
+	say TOSHELL "CALLED-\$counttheme " . dump($counttheme);
+	say TOSHELL "CALLED-\$countreport " . dump($countreport);
+	say TOSHELL "CALLED-\$retfile: " . dump($retfile);
+	say TOSHELL "CALLED-\$repfile: " . dump($repfile);
+	say TOSHELL "CALLED-\$loadsortemps " . dump($loadsortemps);
+	say TOSHELL "repfilemem CALLED " . dump( @repfilemem );
+				
 	my @repfilemem = @$swap; #say TOSHELL "CALLED-\@repfilemem " . dump(@repfilemem);
+	my @retrievs = @$retrievsref;
 	
 	my @measurements_to_report = $retrievs[0]; #say TOSHELL "CALLED-\@measurements_to_report " . dump(@measurements_to_report);
 	my $dates_to_report = $simtitle; #say TOSHELL "CALLED-\$dates_to_report " . dump($dates_to_report);
-	my $tofilter = $reporttempsstats[1]; #say TOSHELL "CALLED-\$tofilter " . dump($tofilter); # , $reportloadsdata[1], @reporttempsstats, @reportradiation, @reportcomfortdata, @reporttempsdata
 	
+	say TOSHELL "CALLED\$loadsortemps: " . $loadsortemps; say TOSHELL "\$retfile! " . $retfile;
 	open( RETFILE,  "$retfile" ) or die "Can't open $retfile $!";
-	my @lines_to_inspect = <RETFILE>; #say TOSHELL "CALLED-\@lines_to_inspect " . dump(@lines_to_inspect);
+	my @lines_to_inspect = <RETFILE>; say TOSHELL "CALLED-\@lines_to_inspect " . dump(@lines_to_inspect);
 
 	my @countcolumns;
 	my $countzones = 0;
@@ -287,16 +284,14 @@ sub get_files
 		if ( $line_to_inspect )
 		{
 			
-			$line_to_inspect =~ s/^\s+//;### DO THIS? ZZZ
+			$line_to_inspect =~ s/^\s+//g;### DO THIS? ZZZ
 			$line_to_inspect =~ s/\s*$//;      #remove trailing whitespace
-			$line_to_inspect =~ s/\ {2,}/ /g;  #remove multiple literal spaces
-			$line_to_inspect =~ s/\t{2,}/\t/g; 
-			my $line_to_report = "$retfile " . "$line_to_inspect"; #say TOSHELL "CALLED-\$line_to_report " . dump($line_to_report); #remove excess tabs  
-			$line_to_report =~ s/--//; 
+			#$line_to_inspect =~ s/\ {2,}/ /g;  #remove multiple literal spaces
+			$line_to_inspect =~ s/\t{2,}/\t/g; say TOSHELL "line_to_inspect: $line_to_inspect";		 
 			
-			if ( $themereport eq "temps" )
+			if ( $themereport eq "temps" ) # NEVER CHECKED IF IT STILL WORKS AFTER SOME USES
 			{
-				my @roww = split( /\s+/, $line_to_report );
+				my @roww = split( /\s+/, $line_to_inspect );
 				if ( $countlines == 1 )
 				{
 					$file_and_period = $roww[5];
@@ -339,9 +334,9 @@ sub get_files
 				$countlines++;
 			}
 			
-			if ( $themereport eq "comfort" )
+			if ( $themereport eq "comfort" ) # NEVER CHECKED IF IT STILL WORKS AFTER SOME USES
 			{				
-				my @roww = split( /\s+/, $line_to_report );
+				my @roww = split( /\s+/, $line_to_inspect );
 
 				if ( $countlines == 1 )
 				{
@@ -386,36 +381,23 @@ sub get_files
 				$countlines++;
 			}
 			
-			if ( $themereport eq "loads" )
+			my $line_to_report;
+			say TOSHELL "\$loadsortemps: $loadsortemps";
+			if ( ( $themereport eq "loads" ) or ( $themereport eq "tempsstats" ) ) 
 			{	
-				if ( $line_to_report =~ /$tofilter/ )
+				if ( $line_to_inspect =~ /^$loadsortemps/ )
 				{
+					$line_to_report = "$retfile " . " $themereport $reporttitle " . $line_to_inspect . " " ;
+					$line_to_report =~ s/--//g;
+					$line_to_report =~ s/\s+/ /g;  #remove multiple literal spaces
+					$line_to_report =~ s/ /,/g;  #remove multiple literal spaces
 					push ( @{ $repfilemem[$countinstance] }, $line_to_report );
 				}
 				$countlines++;
 			}
-			
-			if ( $themereport eq "tempsstats" )
-			{
-				if ( $line_to_report )
-				{
-					"CALLED-\$line_to_report " . dump($line_to_report);
-					#my @roww = split( /\s+/, $line_to_report ); say TOSHELL "CALLED-\@roww " . dump(@roww);
-					#if ( $roww[1] eq "1" or "2" or "3" or "4" or "5" or "6" or "7" or "8" or "9" )
-					#{
-					#	$countzones = $countzones + 1;
-					#}
-					if ( $line_to_report =~ /$tofilter/ )
-					{
-						#say TOSHELL "CALLED-FILTERED-\$line_to_report " . dump($line_to_report);
-						push ( @{ $repfilemem[$countinstance] }, $line_to_report ); say TOSHELL "CALLED-IN-\@repfilemem " . dump(@repfilemem); say TOSHELL "CALLED-IN-\$countinstance " . dump($countinstance);
-					}
-					$countlines++;
-				}
-			}
 		}
 	}
-	say TOSHELL "CALLED-OUT-\@repfilemem " . dump(@repfilemem);
+	say TOSHELL "LEAVING \@repfilemem " . dump(@repfilemem);
 	return (@repfilemem); 
 } # END SUB get_files
 
